# -*- coding: UTF-8 -*-
import re
import json


def get_tags():
    return ['3', '3.2', '3.2.2', '3.2.2.6']


def run_task(runcontext):
    ansible_params = runcontext.get_mod_params_instance()
    runcontext.set_mod_params_instance(ansible_params, "chdir", None)
    runcontext.set_mod_params_instance(ansible_params, "executable", None)
    module = runcontext.get_module_file("shell.py")
    rc, out = run_audit(runcontext, ansible_params, module)
    return rc, out


def run_audit(runcontext, ansible_params, module):
    ret_code = -1
    curtemplate = runcontext.get_template()

    tmp_vars = {}
    tmp_vars["policyresult"] = "failed"
    tmp_vars["checkresult1"] = "failed"
    tmp_vars["checkvalue1"] = ''
    tmp_vars["scancommand1"] = r'''docker -v | awk -F',' '{print $1}' | awk -F' ' '{print $3}' | egrep '[0-1]\.[0-9]\.[0-9]|[0-1]\.1[0-2]\.[0-9]' '''

    tmp_vars["checkresult2"] = "failed"
    tmp_vars["checkvalue2"] = ''
    tmp_vars["scancommand2"] = r'''ps -wef | grep docker | grep "\-\-userland\-proxy=false" | grep -v "grep"'''

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand1"])
    arc1, astdout1, astderr1 = runcontext.invoke_module(module, ansible_params)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand2"])
    arc2, astdout2, astderr2 = runcontext.invoke_module(module, ansible_params)
    runcontext.sleep()

    if arc1 != 0:
        return -2, "Failed to invoke module: %s." % astdout1
    resultjson1 = json.loads(astdout1)
    astdout1 = resultjson1["stdout"]
    astderr1 = resultjson1["stderr"]
    runcontext.log_debug_json(resultjson1)
    match1_found = re.match("^$", astdout1)
    if match1_found:
        if arc2 != 0:
            return -2, "Failed to invoke module: %s." % astdout2
        resultjson2 = json.loads(astdout2)
        astdout2 = resultjson2["stdout"]
        astderr2 = resultjson2["stderr"]
        runcontext.log_debug_json(resultjson2)
        match2_found = re.match(".*--userland-proxy=false.*", astdout2)
        if match2_found is None:
            tmp_vars["checkvalue1"] = astdout2
        else:
            tmp_vars["checkresult1"] = "pass"
            tmp_vars["checkvalue1"] = astdout2
    else:
        tmp_vars["checkresult1"] = "pass"
        tmp_vars["checkvalue1"] = "Applies to docker version 1.13 or later."

    if tmp_vars["checkresult1"] == "pass":
        tmp_vars["policyresult"] = "pass"
        ret_code = 0

    rc, out = curtemplate.render(runcontext.get_template_file('r_3_2_2_6.j2'), **tmp_vars)
    if rc is False:
        return -2, "Failed to render template.%s" % out
    return ret_code, out
