# -*- coding: UTF-8 -*-
import re
import json


def get_tags():
    return ['3', '3.2', '3.2.2', '3.2.2.7']


def run_task(runcontext):
    ansible_params = runcontext.get_mod_params_instance()
    runcontext.set_mod_params_instance(ansible_params, "chdir", None)
    runcontext.set_mod_params_instance(ansible_params, "executable", None)
    module = runcontext.get_module_file("shell.py")
    rc, out = run_audit(runcontext, ansible_params, module)
    return rc, out


def run_audit(runcontext, ansible_params, module):
    ret_code = -1
    curtemplate = runcontext.get_template()

    tmp_vars = {}
    tmp_vars["policyresult"] = "failed"
    tmp_vars["checkresult1"] = "failed"
    tmp_vars["checkvalue1"] = ''
    tmp_vars["scancommand1"] = r'''ps -wef | grep docker | grep "\-\-userns\-remap" | grep -v "grep"'''

    tmp_vars["checkresult2"] = "failed"
    tmp_vars["checkvalue2"] = ''
    tmp_vars["scancommand2"] = r'''data=`docker ps --quiet`;if [ "$data" == "" ]; then echo "file not exist";else for dx in $data;do ps -wp $(docker inspect --format '{{ .State.Pid }}' $dx) -o pid,user | grep 'root';done;fi;'''

    tmp_vars["checkresult3"] = "failed"
    tmp_vars["checkvalue3"] = ''
    tmp_vars["scancommand3"] = '''docker ps --quiet'''

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand1"])
    arc1, astdout1, astderr1 = runcontext.invoke_module(module, ansible_params)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand2"])
    arc2, astdout2, astderr2 = runcontext.invoke_module(module, ansible_params)
    runcontext.sleep()

    runcontext.set_mod_params_instance(ansible_params, "command", tmp_vars["scancommand3"])
    arc3, astdout3, astderr3 = runcontext.invoke_module(module, ansible_params)
    runcontext.sleep()

    if arc1 != 0:
        return -2, "Failed to invoke module: %s." % astdout1
    resultjson1 = json.loads(astdout1)
    astdout1 = resultjson1["stdout"]
    astderr1 = resultjson1["stderr"]
    runcontext.log_debug_json(resultjson1)
    match1_found = re.match(".+", astdout1)
    if match1_found is None:
        tmp_vars["checkvalue1"] = astdout1
    else:
        tmp_vars["checkresult1"] = "pass"
        tmp_vars["checkvalue1"] = astdout1

    if arc2 != 0:
        return -2, "Failed to invoke module: %s." % astdout2
    resultjson2 = json.loads(astdout2)
    astdout2 = resultjson2["stdout"]
    astderr2 = resultjson2["stderr"]
    runcontext.log_debug_json(resultjson2)
    match2_found = re.match(".*root.*", astdout2)
    if match2_found is None:
        tmp_vars["checkresult2"] = "pass"
        tmp_vars["checkvalue2"] = astdout2
    else:
        tmp_vars["checkvalue2"] = astdout2

    if arc3 != 0:
        return -2, "Failed to invoke module: %s." % astdout3
    resultjson3 = json.loads(astdout3)
    astdout3 = resultjson3["stdout"]
    astderr3 = resultjson3["stderr"]
    runcontext.log_debug_json(resultjson3)
    match3_found = re.match(".+", astdout3)
    if match3_found is None:
        tmp_vars["checkvalue3"] = astdout3
    else:
        tmp_vars["checkresult3"] = "pass"
        tmp_vars["checkvalue3"] = astdout3

    if tmp_vars["checkresult1"] == "pass" or (tmp_vars["checkresult2"] == "pass" and tmp_vars["checkresult3"] == "pass"):
        tmp_vars["policyresult"] = "pass"
        ret_code = 0

    rc, out = curtemplate.render(runcontext.get_template_file('r_3_2_2_7.j2'), **tmp_vars)
    if rc is False:
        return -2, "Failed to render template.%s" % out
    return ret_code, out
